==> ameba-0.61.tar.bz2: ameba-0.61/object.h <==
#ifndef _OBJECT_H
#define _OBJECT_H
#include <string>

#include "configs.h"
#include "coordinates.h"

struct Constraint {
    double hold_time;
    double min_alt;
    double max_alt;
    double moon_dist;
    double break_mag;
    double level;
};

class SolarSys {
    Geo* ASM;
    Coord<equ> sun;
public:
    SolarSys( Config& );
    ~SolarSys(){ delete ASM; }
    Coord<ecl> mini_sun( double );
    Coord<ecl> mini_moon (double );
    double set( double );
    double rise( double );
    double sun_altitude() { return sun.alt(); }
};

struct ObjectInfo {
    unsigned int HR;
    std::string name;
    Coord<equ> coords;
    double Vmag;
    double BVcolor;
    std::string spectra;
};

class Object {
    std::vector<ObjectInfo> list;
    std::vector<ObjectInfo> photo;
    std::vector<ObjectInfo> exper;
    Constraint select;
    Geo* ASM;
    SolarSys astro;
    unsigned int current;
    unsigned int count;
    bool mode;
    double fix_time;
    double phot_time;
public:
    Object( Config&, bool );
    ~Object(){ delete ASM; }
    int get_current( ObjectInfo& );
    int get_current_exper( ObjectInfo& );
    int get_next( ObjectInfo& );
    int get_next_exper( ObjectInfo& );
    int get_connected( std::vector<ObjectInfo>& );
    double sun_altitude() { return  astro.sun_altitude(); }
private:
    int get_auto( ObjectInfo& );
    int get_auto_exper( ObjectInfo& );
    int ask_observer( const ObjectInfo& );
};

template<class T, int p> void message( const std::string& s, T a ) {
    std::ostringstream ostr;
    ostr << s << std::fixed << std::setprecision(p) << a;
    ErrlogSingl::instance().write( ostr.str() );
}

template<class T, int p> void message( const std::string& s1, T a1, const std::string& s2, T a2 ) {
    std::ostringstream ostr;
    ostr << s1 << std::fixed << std::setprecision(p) << a1 << " " << s2 << a2;
    ErrlogSingl::instance().write( ostr.str() );
}

inline double BVcolor( const ObjectInfo& s ) {
    return s.BVcolor;
}

inline double MASSmag( const ObjectInfo& s ) {
    return 0.45375*s.BVcolor + 1.0709 + s.Vmag;
}

inline double MASScount( const ObjectInfo& s ) {
    return pow( 10.0, 4.0 - 0.4*MASSmag( s ) );
}

inline int HR( const ObjectInfo& s ) {
    return s.HR;
}

inline std::string Name( const ObjectInfo& s ) {
    return  s.name;
}

inline std::string RA( const ObjectInfo& s ) {
    std::ostringstream str;
    str << s.coords.ra();
    return str.str();
}

inline std::string DEC( const ObjectInfo& s ) {
    std::ostringstream str;
    str << s.coords.dec();
    return str.str();
}

inline std::string OBJECT( const ObjectInfo& s ) {
    std::ostringstream str;
    str << std::fixed << std::setw(4) << s.HR << " " << s.name << " " << s.coords.ra() << " " << s.coords.dec() << " " << std::setprecision(2) << s.Vmag << " " << s.BVcolor << " " << s.spectra;
    return str.str();
}

#endif

==> ameba-1.03.tar.bz2: ameba-1.03/object.h <==
#ifndef _OBJECT_H
#define _OBJECT_H
#include <string>

#include "configs.h"
#include "coordinates.h"

struct Constraint {
    double hold_time;
    double min_alt;
    double max_alt;
    double moon_dist;
    double break_mag;
    double level;
};

class SolarSys {
    Geo* ASM;
    Coord<equ> sun;
public:
    SolarSys( Config& );
    ~SolarSys(){ delete ASM; }
    Coord<ecl> mini_sun( double );
    Coord<ecl> mini_moon (double );
    double set( double );
    double rise( double );
    double sun_altitude() { return sun.alt(); }
};

struct ObjectInfo {
    unsigned int HR;
    std::string name;
    Coord<equ> coords;
    double Vmag;
    double BVcolor;
    std::string spectra;
};

class Object {
    std::vector<ObjectInfo> list;
    std::vector<ObjectInfo> photo;
    std::vector<ObjectInfo> exper;
    Constraint select;
    Geo* ASM;
    SolarSys astro;
    unsigned int current;
    unsigned int count;
    bool mode;
    double fix_time;
    double phot_time;
public:
    Object( Config&, bool );
    ~Object(){ delete ASM; }
    int get_current( ObjectInfo& );
    int get_current_exper( ObjectInfo& );
    int get_next( ObjectInfo& );
    int get_next_exper( ObjectInfo& );
    int get_connected( std::vector<ObjectInfo>& );
    double sun_altitude() { return  astro.sun_altitude(); }
private:
    int get_auto( ObjectInfo& );
    int get_auto_exper( ObjectInfo& );
    int ask_observer( const ObjectInfo& );
};

template<class T, int p> void message( const std::string& s, T a ) {
    std::ostringstream ostr;
    ostr << s << std::fixed << std::setprecision(p) << a;
    ErrlogSingl::instance().write( ostr.str() );
}

template<class T, int p> void message( const std::string& s1, T a1, const std::string& s2, T a2 ) {
    std::ostringstream ostr;
    ostr << s1 << std::fixed << std::setprecision(p) << a1 << " " << s2 << a2;
    ErrlogSingl::instance().write( ostr.str() );
}

inline double BVcolor( const ObjectInfo& s ) {
    return s.BVcolor;
}

// inline double MASSmag( const ObjectInfo& s ) {       //Old mass values
//     return 0.45375*s.BVcolor + 1.0709 + s.Vmag;
// }

inline double MASSmag( const ObjectInfo& s ) {          // New MASS MD09 values (O.Voziakova data)
    return 0.4603*s.BVcolor + 0.005 + s.Vmag;
}

inline double MASScount( const ObjectInfo& s ) {
    return pow( 10.0, 3.57 - 0.4*MASSmag( s ) );
}

inline int HR( const ObjectInfo& s ) {
    return s.HR;
}

inline std::string Name( const ObjectInfo& s ) {
    return  s.name;
}

inline std::string RA( const ObjectInfo& s ) {
    std::ostringstream str;
    str << s.coords.ra();
    return str.str();
}

inline std::string DEC( const ObjectInfo& s ) {
    std::ostringstream str;
    str << s.coords.dec();
    return str.str();
}

inline std::string OBJECT( const ObjectInfo& s ) {
    std::ostringstream str;
    str << std::fixed << std::setw(4) << s.HR << " " << s.name << " " << s.coords.ra() << " " << s.coords.dec() << " " << std::setprecision(2) << s.Vmag << " " << s.BVcolor << " " << s.spectra;
    return str.str();
}

#endif
